@@ -1,11 +1,27 @@
 package Bio::ToolBox::parser::gff;
 
-our $VERSION = '1.54';
+our $VERSION = '1.62';
 
 =head1 NAME
 
 Bio::ToolBox::parser::gff - parse GFF3, GTF, and GFF files 
 
+=head1 SYNOPSIS
+
+  use Bio::ToolBox::parser::gff;
+  my $filename = 'file.gff3';
+  
+  my $parser = Bio::ToolBox::parser::gff->new(
+  	file    => $filename,
+  	do_gene => 1,
+  	do_exon => 1,
+  ) or die "unable to open gff file!\n";
+  
+  while (my $feature = $parser->next_top_feature() ) {
+	# each $feature is a SeqFeature object
+	my @children = $feature->get_SeqFeatures();
+  }
+
 =head1 DESCRIPTION
 
 This module parses a GFF file into SeqFeature objects. It natively 
@@ -29,22 +45,6 @@ Embedded Fasta sequences are ignored, as are most comment and pragma lines.
 The SeqFeature objects that are returned are L<Bio::ToolBox::SeqFeature> 
 objects. Refer to that documentation for more information.
 
-=head1 SYNOPSIS
-
-  use Bio::ToolBox::parser::gff;
-  my $filename = 'file.gff3';
-  
-  my $parser = Bio::ToolBox::parser::gff->new(
-  	file    => $filename,
-  	do_gene => 1,
-  	do_exon => 1,
-  ) or die "unable to open gff file!\n";
-  
-  while (my $feature = $parser->next_top_feature() ) {
-	# each $feature is a SeqFeature object
-	my @children = $feature->get_SeqFeatures();
-  }
-
 =head1 METHODS
 
 =head2 Initialize and modify the parser. 
@@ -286,9 +286,8 @@ L<Bio::ToolBox::SeqFeature>, L<Bio::ToolBox::parser::ucsc>, L<Bio::Tools::GFF>
 use strict;
 use Carp qw(carp cluck croak);
 use Bio::ToolBox::Data::file; 
-our $SFCLASS = 'Bio::ToolBox::SeqFeature'; # alternative to Bio::SeqFeature::Lite
+my $SFCLASS = 'Bio::ToolBox::SeqFeature'; # alternative to Bio::SeqFeature::Lite
 eval "require $SFCLASS" or croak $@;
-our $gff_convertor_sub; # reference to the gff convertor subroutine
 
 1;
 
@@ -312,6 +311,7 @@ sub new {
 		'seq_ids'       => {},
 		'simplify'      => 0,
 		'typelist'      => '',
+		'convertor_sub' => undef,
 	};
 	bless $self, $class;
 	
@@ -404,6 +404,16 @@ sub do_codon {
 	return $self->{'do_codon'};
 }	
 
+sub do_name {
+	# this does nothing other than maintain compatibility with ucsc parser
+	return 0;
+}	
+
+sub share {
+	# this does nothing other than maintain compatibility with ucsc parser
+	return 1;
+}	
+
 sub simplify {
 	my $self = shift;
 	if (defined $_[0]) {
@@ -499,7 +509,7 @@ sub next_feature {
 	return if $self->{'eof'};
 	
 	# check convertor
-	unless (defined $gff_convertor_sub) {
+	unless (defined $self->{convertor_sub}) {
 		$self->_assign_gff_converter;
 	}
 	
@@ -552,41 +562,41 @@ sub next_feature {
 		my $type = lc $fields[2];
 		if ($type eq 'cds') {
 			if ($self->do_cds) {
-				return &$gff_convertor_sub($self, \@fields);
+				return &{$self->{convertor_sub}}($self, \@fields);
 			} else {
 				next;
 			}
 		}
 		elsif ($type eq 'exon') {
 			if ($self->do_exon) {
-				return &$gff_convertor_sub($self, \@fields);
+				return &{$self->{convertor_sub}}($self, \@fields);
 			} else {
 				next;
 			}
 		}
 		elsif ($type =~ /utr|untranslated/) {
 			if ($self->do_utr) {
-				return &$gff_convertor_sub($self, \@fields);
+				return &{$self->{convertor_sub}}($self, \@fields);
 			} else {
 				next;
 			}
 		}
 		elsif ($type =~ /codon/) {
 			if ($self->do_codon) {
-				return &$gff_convertor_sub($self, \@fields);
+				return &{$self->{convertor_sub}}($self, \@fields);
 			} else {
 				next;
 			}
 		}
 		elsif ($type =~ /gene$/) {
 			if ($self->do_gene) {
-				return &$gff_convertor_sub($self, \@fields);
+				return &{$self->{convertor_sub}}($self, \@fields);
 			} else {
 				next;
 			}
 		}
 		elsif ($type =~ /transcript|rna/) {
-			return &$gff_convertor_sub($self, \@fields);
+			return &{$self->{convertor_sub}}($self, \@fields);
 		}
 		elsif ($type =~ /chromosome|contig|scaffold/) {
 			# gff3 files can record the chromosome as a gff record
@@ -597,7 +607,7 @@ sub next_feature {
 		else {
 			# everything else must be some non-standard weird element
 			# only process this if the user wants everything
-			return &$gff_convertor_sub($self, \@fields) unless $self->simplify;
+			return &{$self->{convertor_sub}}($self, \@fields) unless $self->simplify;
 		}
 	}
 	
@@ -924,26 +934,26 @@ sub from_gff_string {
 	my @fields = split('\t', $string);
 	
 	# check convertor
-	unless (defined $gff_convertor_sub) {
+	unless (defined $self->{convertor_sub}) {
 		$self->_assign_gff_converter;
 	}
 	
 	# parse appropriately
-	return &$gff_convertor_sub($self, \@fields);
+	return &{$self->{convertor_sub}}($self, \@fields);
 }
 
 
 sub _assign_gff_converter {
 	my $self = shift;
 	if ($self->{gff3}) {
-		$gff_convertor_sub =\&_gff3_to_seqf;
+		$self->{convertor_sub} = \&_gff3_to_seqf;
 	}
 	elsif ($self->{gtf}) {
 		if ($self->simplify) {
-			$gff_convertor_sub = \&_gtf_to_seqf_simple;
+			$self->{convertor_sub} = \&_gtf_to_seqf_simple;
 		}
 		else {
-			$gff_convertor_sub = \&_gtf_to_seqf_full;
+			$self->{convertor_sub} = \&_gtf_to_seqf_full;
 		}
 		# double check we have transcript information
 		if ($self->typelist !~ /transcript|rna/i) {
@@ -957,7 +967,7 @@ sub _assign_gff_converter {
 		}
 	}
 	else {
-		$gff_convertor_sub = \&_gff2_to_seqf;
+		$self->{convertor_sub} = \&_gff2_to_seqf;
 	}
 }
 
