@@ -9,14 +9,11 @@ use Bio::ToolBox::Data;
 use Bio::ToolBox::db_helper qw(verify_or_request_feature_types);
 use Bio::ToolBox::GeneTools qw(
 	:export 
-	get_transcripts
-	collapse_transcripts
-	filter_transcript_support_level
-	filter_transcript_gencode_basic
-	filter_transcript_biotype
+	:filter
+	:transcript
 );
 use Bio::ToolBox::utility;
-my $VERSION = '1.61';
+my $VERSION = '1.62';
 
 print "\n This program will collect features from annotation sources\n\n";
 
@@ -102,7 +99,12 @@ if ($help) {
 
 # Print version
 if ($print_version) {
-	print " Biotoolbox script <NAME>.pl, version $VERSION\n\n";
+	print " Biotoolbox script get_features.pl, version $VERSION\n";
+	eval {
+		require Bio::ToolBox;
+		my $v = Bio::ToolBox->VERSION;
+		print " Biotoolbox package version $v\n";
+	};
 	exit;
 }
 
@@ -126,6 +128,12 @@ filter_features();
 
 
 ### Write out file
+if ($start_adj or $stop_adj) {
+	printf " Adjusting start by %s bp and stop by %s bp relative to position %s\n",
+		$start_adj, $stop_adj, $position eq '5' ? 'start' : $position eq '3' ? 'end' : 
+		$position eq '4' or $position eq 'm' ? 'middle' : $position eq '53' ? 'both ends' :
+		'neither';
+}
 if ($convert_to_bed) {
 	print " Writing to bed file...\n";
 	export_to_bed();
@@ -185,16 +193,21 @@ sub check_requirements {
 	
 	# check collapse
 	if ($collapse) {
-		unless ($convert_to_gff or $convert_to_gtf or $convert_to_refflat) {
-			die " Cannot collapse transcripts unless writing to GFF/GTF/refFlat!\n";
+		unless ($get_subfeatures) {
+			die " Cannot collapse transcript unless subfeatures are turned on!\n";
+		}
+		unless ($convert_to_gff or $convert_to_gtf or $convert_to_refflat or 
+				$convert_to_bed
+		) {
+			die " Cannot collapse transcripts unless writing to BED12/GFF/GTF/refFlat!\n";
 		}
 	}
 	
 	# check adjustments
 	if ($start_adj or $stop_adj) {
 		# automatically include coordinates if we're adjusting them
-		if ($convert_to_gff or $convert_to_gtf or $convert_to_refflat) {
-			die " Cannot adjust coordinates when converting to GFF/GTF/refFlat!\n";
+		if ($get_subfeatures) {
+			die " Cannot adjust coordinates when including subfeatures!\n";
 		}
 		$include_coordinates = 1;
 	}
@@ -236,7 +249,7 @@ sub load_from_database {
 	# validate and/or request features
 	@features = verify_or_request_feature_types(
 		'db'      => $database,
-		'feature' => [ @features ],
+		'feature' => \@features,
 		'prompt'  => " Enter the feature(s) to collect." . 
 				" A comma de-limited list or range may be given\n",
 	) or die " no valid features were provided! see help\n";
@@ -383,11 +396,12 @@ sub filter_features {
 sub export_to_bed {
 	# prepare output
 	my $outData = Bio::ToolBox::Data->new(
-		bed => 6,
+		bed => $get_subfeatures ? 12 : 6,
 	) or die "unable to create output Data structure!\n";
 	
-	# adjust coordinates as necessary and write
+	# Write method based on subfeatures or coordinate adjustment
 	if ($start_adj or $stop_adj) {
+		# adjust coordinates as necessary and write a BED6 file
 		$Data->iterate( sub {
 			my $row = shift;
 			my $f = $row->seqfeature(1); # make sure we get the seqfeature
@@ -400,7 +414,23 @@ sub export_to_bed {
 			$Data->delete_seqfeature($row->row_index);
 		});
 	}
+	elsif ($get_subfeatures) {
+		# write transcripts as BED12
+		if ($features[0] =~ /gene/i) {
+			print " NOTE: gene information is discarded when writing BED12\n";
+		}
+		$Data->iterate( sub {
+			my $row = shift;
+			my $f = $row->seqfeature(1); # make sure we get the seqfeature
+			my $string = bed_string($f);
+			foreach (split /\n/, $string) {
+				$outData->add_row($_);
+			}
+			$Data->delete_seqfeature($row->row_index);
+		});
+	}
 	else {
+		# write ordinary BED6
 		$Data->iterate( sub {
 			my $row = shift;
 			my $f = $row->seqfeature(1); # make sure we get the seqfeature
@@ -409,6 +439,7 @@ sub export_to_bed {
 			$Data->delete_seqfeature($row->row_index);
 		});
 	}
+	print " done\n";
 	
 	# sort as necessary
 	if ($sort_data) {
@@ -536,7 +567,7 @@ sub export_to_gtf {
 
 sub export_to_txt {
 	# adjust coordinates as necessary
-	if (($start_adj or $stop_adj) or $include_coordinates) {
+	if ($start_adj or $stop_adj) {
 		
 		# make sure we establish the feature type first, before we add 
 		# coordinate columns, otherwise features might not be returned properly
@@ -559,6 +590,29 @@ sub export_to_txt {
 			$row->value($strand_i, $f->strand);
 		});
 	}
+	elsif ($include_coordinates) {
+		# just include original coordinates
+		
+		# make sure we establish the feature type first, before we add 
+		# coordinate columns, otherwise features might not be returned properly
+		my $ftype = $Data->feature_type;
+		
+		# add coordinate columns
+		my $seq_i    = $Data->add_column('Chromosome');
+		my $start_i  = $Data->add_column('Start');
+		my $stop_i   = $Data->add_column('Stop');
+		my $strand_i = $Data->add_column('Strand');
+		
+		# iterate
+		$Data->iterate( sub {
+			my $row = shift;
+			my $f = $row->seqfeature(1);
+			$row->value($seq_i, $f->seq_id);
+			$row->value($start_i, $f->start);
+			$row->value($stop_i, $f->stop);
+			$row->value($strand_i, $f->strand);
+		});
+	}
 	
 	# collect attribute tags, this does not recurse
 	if (@include_tags) {
@@ -657,18 +711,30 @@ sub adjust_coordinates {
 			if ($start_adj) {
 				$start = $fstart + $start_adj;
 			}
+			else {
+				$start = $fstart;
+			}
 			if ($stop_adj) {
 				$end = $fstart + $stop_adj;
 			}
+			else {
+				$end = $fstart;
+			}
 		}
 		else {
 			# reverse strand
 			if ($start_adj) {
 				$end = $fend - $start_adj;
 			}
+			else {
+				$end = $fend;
+			}
 			if ($stop_adj) {
 				$start = $fend - $stop_adj;
 			}
+			else {
+				$start = $fend;
+			}
 		}
 	}
 	
@@ -680,18 +746,30 @@ sub adjust_coordinates {
 			if ($start_adj) {
 				$end = $fend + $start_adj;
 			}
+			else {
+				$end = $fend;
+			}
 			if ($stop_adj) {
 				$start = $fend + $stop_adj;
 			}
+			else {
+				$start = $fend;
+			}
 		}
 		else {
 			# reverse strand
 			if ($start_adj) {
 				$start = $fstart - $start_adj;
 			}
+			else {
+				$start = $fstart;
+			}
 			if ($stop_adj) {
 				$end = $fstart - $stop_adj;
 			}
+			else {
+				$end = $fstart;
+			}
 		}
 	}
 	
@@ -704,18 +782,30 @@ sub adjust_coordinates {
 			if ($start_adj) {
 				$start = $midpoint + $start_adj;
 			}
+			else {
+				$start = $midpoint;
+			}
 			if ($stop_adj) {
 				$end = $midpoint + $stop_adj;
 			}
+			else {
+				$end = $midpoint;
+			}
 		}
 		else {
 			# reverse strand
 			if ($start_adj) {
 				$end = $midpoint - $start_adj;
 			}
+			else {
+				$end = $midpoint;
+			}
 			if ($stop_adj) {
 				$start = $midpoint - $stop_adj;
 			}
+			else {
+				$start = $midpoint;
+			}
 		}
 	}
 	
@@ -727,18 +817,30 @@ sub adjust_coordinates {
 			if ($start_adj) {
 				$start = $fstart + $start_adj;
 			}
+			else {
+				$start = $fstart;
+			}
 			if ($stop_adj) {
 				$end = $fend + $stop_adj;
 			}
+			else {
+				$end = $fend;
+			}
 		}
 		else {
 			# reverse strand
 			if ($start_adj) {
 				$end = $fend - $start_adj;
 			}
+			else {
+				$end = $fend;
+			}
 			if ($stop_adj) {
 				$start = $fstart - $stop_adj;
 			}
+			else {
+				$start = $fstart;
+			}
 		}
 	}
 	
@@ -781,7 +883,7 @@ get_features.pl --db E<lt>nameE<gt> --out E<lt>filenameE<gt>
   
   Selection:
   -f --feature <type>           feature: gene, mRNA, transcript, etc
-  -u --sub                      include subfeatures (true if gff, gtf, refFlat out)
+  -u --sub                      include subfeatures (true if gff, gtf, refFlat)
   
   Filter features:
   -K --chrskip <regex>          skip features from certain chromosomes
@@ -799,10 +901,10 @@ get_features.pl --db E<lt>nameE<gt> --out E<lt>filenameE<gt>
   --collapse                    collapse subfeatures from alt transcripts
   
   Report format options:
-  -B --bed                      write in BED6 format
-  -G --gff                      write in GFF3 format
-  -g --gtf                      write in GTF format
-  -r --refflat                  write in UCSC refFlat format
+  -B --bed                      write BED6 (no --sub) or BED12 (--sub) format
+  -G --gff                      write GFF3 format
+  -g --gtf                      write GTF format
+  -r --refflat                  write UCSC refFlat format
   -t --tag <text>               include specific GFF attributes in text output
   --coord                       include coordinates in text output
   
@@ -854,7 +956,8 @@ from which one or more may be chosen.
 Optionally include all child subfeatures in the output. For example, 
 transcript, CDS, and/or exon subfeatures of a gene. This option is 
 automatically enabled with GFF, GTF, or refFlat output; it may be 
-turned off with C<--nosub>. It has no effect with standard text or BED output.
+turned off with C<--nosub>. With BED output, it will force a BED12 
+file to be written. It has no effect with standard text. 
 
 =back
 
@@ -929,8 +1032,8 @@ end coordinates of the collected regions. A negative value is shifted
 upstream (towards the 5 prime end), and a positive value is shifted 
 downstream (towards the 3 prime end). Adjustments are made relative 
 to the indicated position (--pos option, below) based on the feature 
-strand. Adjustments are only allowed when writing BED or standard 
-text files.
+strand. Adjustments are only allowed when writing standard BED6 or 
+standard text files.
 
 =item --pos [ 5 | m | 3 | 53 ]
 
@@ -956,7 +1059,8 @@ collapsed.
 
 =item --bed
 
-Write a standard 6-column BED format file. Subfeatures are not included.
+With subfeatures enabled, write a BED12 (12-column BED) file. 
+Otherwise, write a standard 6-column BED format file. 
 
 =item --gff
 
